#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_REAL_SPLAT_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_REAL_SPLAT_HPP_INCLUDED

#include <boost/simd/constant/include/constants/real_splat.hpp>

#endif
